@@ -233,6 +233,118 @@ func TestByNumberAndComponent(t *testing.T) {
 	}
 }
 
+func TestShiftOrder(t *testing.T) {
+	tasks := func(names ...string) []*Task {
+		var arr []*Task
+		for _, name := range names {
+			arr = append(arr, &Task{Manifest: &lib.Manifest{OriginalFilename: name}})
+		}
+		return arr
+	}
+	tests := []struct {
+		name   string
+		step   int
+		stride int
+		tasks  [][]*TaskNode
+		want   [][]*TaskNode
+	}{
+		{
+			step:   0,
+			stride: 8,
+			tasks: [][]*TaskNode{
+				{
+					&TaskNode{Tasks: tasks("0000_01_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_02_x-y-z_file1")},
+				},
+			},
+			want: [][]*TaskNode{
+				{
+					&TaskNode{Tasks: tasks("0000_01_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_02_x-y-z_file1")},
+				},
+			},
+		},
+		{
+			step:   1,
+			stride: 8,
+			tasks: [][]*TaskNode{
+				{
+					&TaskNode{Tasks: tasks("0000_01_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_02_x-y-z_file1")},
+				},
+			},
+			want: [][]*TaskNode{
+				{
+					&TaskNode{Tasks: tasks("0000_02_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_01_x-y-z_file1")},
+				},
+			},
+		},
+		{
+			step:   2,
+			stride: 8,
+			tasks: [][]*TaskNode{
+				{
+					&TaskNode{Tasks: tasks("0000_01_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_02_x-y-z_file1")},
+				},
+			},
+			want: [][]*TaskNode{
+				{
+					&TaskNode{Tasks: tasks("0000_01_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_02_x-y-z_file1")},
+				},
+			},
+		},
+		{
+			step:   1,
+			stride: 2,
+			tasks: [][]*TaskNode{
+				{
+					&TaskNode{Tasks: tasks("0000_01_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_02_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_03_x-y-z_file1")},
+				},
+			},
+			want: [][]*TaskNode{
+				{
+					&TaskNode{Tasks: tasks("0000_02_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_03_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_01_x-y-z_file1")},
+				},
+			},
+		},
+		{
+			step:   2,
+			stride: 3,
+			tasks: [][]*TaskNode{
+				{
+					&TaskNode{Tasks: tasks("0000_01_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_02_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_03_x-y-z_file1")},
+				},
+			},
+			want: [][]*TaskNode{
+				{
+					&TaskNode{Tasks: tasks("0000_03_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_01_x-y-z_file1")},
+					&TaskNode{Tasks: tasks("0000_02_x-y-z_file1")},
+				},
+			},
+		},
+	}
+	for _, test := range tests {
+		t.Run(test.name, func(t *testing.T) {
+			fn := func([]*Task) [][]*TaskNode {
+				return test.tasks
+			}
+			if out := ShiftOrder(fn, test.step, test.stride)(nil); !reflect.DeepEqual(test.want, out) {
+				t.Errorf("%s", diff.ObjectReflectDiff(test.want, out))
+			}
+		})
+	}
+}
+
 func TestFlattenByNumberAndComponent(t *testing.T) {
 	tasks := func(names ...string) []*Task {
 		var arr []*Task
@@ -609,14 +721,12 @@ func TestRunGraph(t *testing.T) {
 		wantErrs   []string
 	}{
 		{
-			name: "tasks executed in order",
 			nodes: []*TaskNode{
 				{Tasks: tasks("a", "b")},
 			},
 			order: []string{"a", "b"},
 		},
 		{
-			name: "nodes executed after dependencies",
 			nodes: []*TaskNode{
 				{Tasks: tasks("c"), In: []int{3}},
 				{Tasks: tasks("d", "e"), In: []int{3}},
@@ -646,7 +756,6 @@ func TestRunGraph(t *testing.T) {
 			},
 		},
 		{
-			name: "mid-task cancellation error interrupts node processing",
 			nodes: []*TaskNode{
 				{Tasks: tasks("c"), In: []int{2}},
 				{Tasks: tasks("d"), In: []int{2}, Out: []int{3}},
@@ -672,7 +781,6 @@ func TestRunGraph(t *testing.T) {
 			},
 		},
 		{
-			name: "task error interrupts node processing",
 			nodes: []*TaskNode{
 				{Tasks: tasks("c"), In: []int{2}},
 				{Tasks: tasks("d"), In: []int{2}, Out: []int{3}},
@@ -688,15 +796,15 @@ func TestRunGraph(t *testing.T) {
 					case <-time.After(time.Second):
 						t.Fatalf("expected context")
 					case <-ctx.Done():
-						t.Logf("got canceled context")
-						return ctx.Err()
+						t.Logf("got cancelled context")
+						return fmt.Errorf("cancelled")
 					}
 					return fmt.Errorf("error A")
 				}
 				return nil
 			},
 			want:     []string{"a", "b", "c"},
-			wantErrs: []string{"context canceled"},
+			wantErrs: []string{"cancelled"},
 			invariants: func(t *testing.T, got []string) {
 				for _, s := range got {
 					if s == "e" {
@@ -706,7 +814,6 @@ func TestRunGraph(t *testing.T) {
 			},
 		},
 		{
-			name: "task errors in parallel nodes both reported",
 			nodes: []*TaskNode{
 				{Tasks: tasks("a"), Out: []int{1}},
 				{Tasks: tasks("b"), In: []int{0}, Out: []int{2, 4, 8}},
@@ -732,26 +839,6 @@ func TestRunGraph(t *testing.T) {
 			want:     []string{"a", "b", "d1", "d2", "d3"},
 			wantErrs: []string{"error - c1", "error - f"},
 		},
-		{
-			name: "cancelation without task errors is reported",
-			nodes: []*TaskNode{
-				{Tasks: tasks("a"), Out: []int{1}},
-				{Tasks: tasks("b"), In: []int{0}},
-			},
-			sleep:    time.Millisecond,
-			parallel: 1,
-			errorOn: func(t *testing.T, name string, ctx context.Context, cancelFn func()) error {
-				if name == "a" {
-					cancelFn()
-					time.Sleep(time.Second)
-					return nil
-				}
-				t.Fatalf("task b should never run")
-				return nil
-			},
-			want:     []string{"a"},
-			wantErrs: []string{"context canceled"},
-		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
